==> sale-3.5.3.jar: revenue/sqls/FileManage/nc/getGroupRecord.sql <==
select id,             //操作id
	   type,           //操作类型
	   f_describe,     //描述
	   f_state,        //状态
	   f_operator,     //操作员
	   f_operate_date,  //操作时间
	   f_userinfo_id,   //用户编号
	   f_userinfo_code,
	   f_user_id,		//表编号
	   f_userfiles_id,
	   '正常' f_user_state,
	   f_cancel_record_id,  //显示撤销操作的编号
	   f_cancel_reason,  //撤销原因
	   g_orgid,
	   1 state,
	   f_comments,  //备注
	   f_user_type,
	   f_gasproperties
from
 (
	select { entity.findDialect() == $SqlServer$: $top (select isnull((SELECT cast(value as int) FROM  t_singlevalue WHERE name='操作记录条数'  ),20))$,$$} p.*
	from
	(
		select
		  r.id,r.f_operat_type type,r.f_describe,r.f_state,r.f_operator,r.f_cancel_record_id,
		  r.f_cancel_reason,r.f_operate_date,r.f_userinfo_id,r.f_userinfo_code,r.f_user_id,
		  r.f_userfiles_id,f_comments,g_orgid,r.f_user_type,r.f_gasproperties
		from
		    (
		      select { entity.findDialect() == $SqlServer$: $top (select isnull((SELECT cast(value as int) FROM  t_singlevalue WHERE name='操作记录条数'  ),20))$,$$}
		         r.id,
             r.f_operat_type,
             r.f_describe,
             r.f_state,
             r.f_operator,
             r.f_operate_date,
             r.f_user_id,
             r.f_userfiles_id,
             isnull(s.f_customer, r.f_userinfo_id)  f_userinfo_code,
             r.f_userinfo_id,
             r.f_cancel_record_id,
             r.f_cancel_reason,
             g.f_orgid g_orgid,
             r.f_comments,
             s.f_user_type,
             s.f_gasproperties
          from t_record r
          left join t_sellinggasbatch s on r.id=s.id
          left join (select id,f_orgid from  t_gasloss) g on r.id=g.id
		      where {condition} and r.f_operat_type in ('团体收费','团体退费','发磁条卡','补磁条卡','团体收费撤销','团体补费','团体扣费') and r.f_state != '无效'
		      order by id desc
		    ) r
		   { entity.findDialect() == $SqlServer$: $$,$and rownum<=(SELECT cast(value as int) FROM  t_singlevalue WHERE name='操作记录条数'  )$}
   ) p { entity.findDialect() == $SqlServer$: $$,$where rownum<=80$}
 )  ss
order by id desc

==> sale-3.7.1.jar: revenue/sqls/FileManage/nc/getGroupRecord.sql <==
select id,             //操作id
	   type,           //操作类型
	   f_describe,     //描述
	   f_state,        //状态
	   f_operator,     //操作员
	   f_operate_date,  //操作时间
	   f_userinfo_id,   //用户编号
	   f_userinfo_code,
	   f_user_id,		//表编号
	   f_userfiles_id,
	   '正常' f_user_state,
	   f_cancel_record_id,  //显示撤销操作的编号
	   f_cancel_reason,  //撤销原因
	   g_orgid,
	   1 state,
	   f_comments,  //备注
	   f_user_type,
	   f_gasproperties,
       f_charge_user
from
 (
	select { entity.findDialect() == $SqlServer$: $top (select isnull((SELECT cast(value as int) FROM  t_singlevalue WHERE name='操作记录条数'  ),20))$,$$} p.*
	from
	(
		select
		  r.id,r.f_operat_type type,r.f_describe,r.f_state,r.f_operator,r.f_cancel_record_id,
		  r.f_cancel_reason,r.f_operate_date,r.f_userinfo_id,r.f_userinfo_code,r.f_user_id,
		  r.f_userfiles_id,f_comments,g_orgid,r.f_user_type,r.f_gasproperties,f_charge_user
		from
		    (
		      select { entity.findDialect() == $SqlServer$: $top (select isnull((SELECT cast(value as int) FROM  t_singlevalue WHERE name='操作记录条数'  ),20))$,$$}
		         r.id,
             r.f_operat_type,
             r.f_describe,
             r.f_state,
             r.f_operator,
             r.f_operate_date,
             r.f_user_id,
             r.f_userfiles_id,
             isnull(s.f_customer, r.f_userinfo_id)  f_userinfo_code,
             r.f_userinfo_id,
             r.f_cancel_record_id,
             r.f_cancel_reason,
             g.f_orgid g_orgid,
             r.f_comments,
             s.f_user_type,
             s.f_gasproperties,
             s.f_charge_user
          from t_record r
          left join t_sellinggasbatch s on r.id=s.id
          left join (select id,f_orgid from  t_gasloss) g on r.id=g.id
		      where {condition} and r.f_operat_type in ('团体收费','团体退费','发磁条卡','团体调价补费','团体调价补费撤销','补磁条卡','团体收费撤销','团体补费','团体扣费') and r.f_state != '无效'
		      order by id desc
		    ) r
		   { entity.findDialect() == $SqlServer$: $$,$and rownum<=(SELECT cast(value as int) FROM  t_singlevalue WHERE name='操作记录条数'  )$}
   ) p { entity.findDialect() == $SqlServer$: $$,$where rownum<=80$}
 )  ss
order by id desc
